==> estateplat-common-1.2.4-20181227.092346-78-sources.jar: cn/gtmap/estateplat/model/server/core/BdcXtDamlh.java <==
package cn.gtmap.estateplat.model.server.core;

import javax.persistence.Id;
import javax.persistence.Table;
import java.io.Serializable;

/**
 * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
 * @version 1.0, 2016/5/2
 * @description 不动产登记档案目录号的配置
 */
@Table(name = "bdc_xt_damlh")
public class BdcXtDamlh implements Serializable {
    @Id
    private String id;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @version 1.0, 2016/5/2
     * @description 不动产类型
     */
    private String bdclx;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @version 1.0, 2016/5/2
     * @description 证书类型
     */
    private String zslx;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @version 1.0, 2016/5/2
     * @description 档案目录号
     */
    private String mlh;

    private String djlx;//登记类型
    private String dwdm;//单位代码

    public String getDjlx() {
        return djlx;
    }

    public void setDjlx(String djlx) {
        this.djlx = djlx;
    }

    public String getDwdm() {
        return dwdm;
    }

    public void setDwdm(String dwdm) {
        this.dwdm = dwdm;
    }

    public String getId() {
        return id;
    }

    public void setId(String id) {
        this.id = id;
    }

    public String getBdclx() {
        return bdclx;
    }

    public void setBdclx(String bdclx) {
        this.bdclx = bdclx;
    }

    public String getZslx() {
        return zslx;
    }

    public void setZslx(String zslx) {
        this.zslx = zslx;
    }

    public String getMlh() {
        return mlh;
    }

    public void setMlh(String mlh) {
        this.mlh = mlh;
    }
}

==> estateplat-common-1.2.4-20190408.063121-130-sources.jar: cn/gtmap/estateplat/model/server/core/BdcXtDamlh.java <==
package cn.gtmap.estateplat.model.server.core;

import javax.persistence.Id;
import javax.persistence.Table;
import java.io.Serializable;

/**
 * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
 * @version 1.0, 2016/5/2
 * @description 不动产登记档案目录号的配置
 */
@Table(name = "bdc_xt_damlh")
public class BdcXtDamlh implements Serializable {
    @Id
    private String id;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @version 1.0, 2016/5/2
     * @description 不动产类型
     */
    private String bdclx;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @version 1.0, 2016/5/2
     * @description 证书类型
     */
    private String zslx;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @version 1.0, 2016/5/2
     * @description 档案目录号
     */
    private String mlh;

    private String djlx;//登记类型
    private String dwdm;//单位代码
    private String sqlxdm;//申请类型
    private String bgqx;//保管期限

    public String getDjlx() {
        return djlx;
    }

    public void setDjlx(String djlx) {
        this.djlx = djlx;
    }

    public String getDwdm() {
        return dwdm;
    }

    public void setDwdm(String dwdm) {
        this.dwdm = dwdm;
    }

    public String getId() {
        return id;
    }

    public void setId(String id) {
        this.id = id;
    }

    public String getBdclx() {
        return bdclx;
    }

    public void setBdclx(String bdclx) {
        this.bdclx = bdclx;
    }

    public String getZslx() {
        return zslx;
    }

    public void setZslx(String zslx) {
        this.zslx = zslx;
    }

    public String getMlh() {
        return mlh;
    }

    public void setMlh(String mlh) {
        this.mlh = mlh;
    }

    public String getSqlxdm() {
        return sqlxdm;
    }

    public void setSqlxdm(String sqlxdm) {
        this.sqlxdm = sqlxdm;
    }

    public String getBgqx() {
        return bgqx;
    }

    public void setBgqx(String bgqx) {
        this.bgqx = bgqx;
    }
}
